@@ -229,8 +229,12 @@ function onViewToolbarCommand(aEvent, toolboxId)
   var index = aEvent.originalTarget.getAttribute("toolbarindex");
   var toolbar = toolbox.childNodes[index];
 
-  toolbar.collapsed = aEvent.originalTarget.getAttribute("checked") != "true";
-  document.persist(toolbar.id, "collapsed");
+  var hidingAttribute = toolbar.getAttribute("type") == "menubar" ?
+                        "autohide" : "collapsed";
+
+  toolbar.setAttribute(hidingAttribute,
+                       aEvent.originalTarget.getAttribute("checked") != "true");
+  document.persist(toolbar.id, hidingAttribute);
 }
 
 function onViewToolbarsPopupShowing(aEvent, toolboxId)
@@ -250,14 +254,15 @@ function onViewToolbarsPopupShowing(aEvent, toolboxId)
   for (var i = 0; i < toolbox.childNodes.length; ++i) {
     var toolbar = toolbox.childNodes[i];
     var toolbarName = toolbar.getAttribute("toolbarname");
-    var type = toolbar.getAttribute("type");
-    if (toolbarName && type != "menubar") {
-      var menuItem = document.createElement("menuitem");
+    if (toolbarName) {
+      let menuItem = document.createElement("menuitem");
+      let hidingAttribute = toolbar.getAttribute("type") == "menubar" ?
+                            "autohide" : "collapsed";
       menuItem.setAttribute("toolbarindex", i);
       menuItem.setAttribute("type", "checkbox");
       menuItem.setAttribute("label", toolbarName);
       menuItem.setAttribute("accesskey", toolbar.getAttribute("accesskey"));
-      menuItem.setAttribute("checked", toolbar.getAttribute("collapsed") != "true");
+      menuItem.setAttribute("checked", toolbar.getAttribute(hidingAttribute) != "true");
       popup.insertBefore(menuItem, firstMenuItem);
       menuItem.addEventListener("command",
         function(aEvent) { onViewToolbarCommand(aEvent, toolboxId); }, false);
@@ -435,9 +440,9 @@ function openAboutDialog()
     return;
   }
 
-//@line 480 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
+//@line 485 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
   var features = "chrome,centerscreen,dependent,dialog=no";
-//@line 482 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
+//@line 487 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
   window.openDialog("chrome://messenger/content/aboutDialog.xul", "About", features);
 }
 
@@ -498,13 +503,13 @@ function safeModeRestart()
   }
 }
 
-//@line 545 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
+//@line 550 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
 
 function getMostRecentMailWindow() {
   let wm = Cc["@mozilla.org/appshell/window-mediator;1"]
              .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 551 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
+//@line 556 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
   let win = wm.getMostRecentWindow("mail:3pane", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -518,7 +523,7 @@ function getMostRecentMailWindow() {
         win = nextWin;
     }
   }
-//@line 577 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
+//@line 582 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
 
   return win;
 }
@@ -537,7 +542,7 @@ function SanitizeAttachmentDisplayName(aAttachment)
 {
   let displayName = aAttachment.name.trim();
   return displayName.replace(/\s+/g, " ")
-//@line 598 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
+//@line 603 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
                     .replace(/(.)\1{9,}/g, "$1…$1");
 }
 
