@@ -1,4 +1,6 @@
-//@line 37 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-miramar/mozilla/toolkit/mozapps/extensions/content/eula.js"
+//@line 37 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mozilla/toolkit/mozapps/extensions/content/eula.js"
+
+"use strict";
 
 function Startup() {
   var bundle = document.getElementById("extensionsStrings");
